@@ -1,3 +1,7 @@
+# For mocking in test
+utils_download_file <- function(...){
+  utils_download_file(...)
+}
 #' Use Files
 #'
 #' These functions download files from external sources and put them inside the `inst/app/www` directory.
@@ -18,12 +22,12 @@
 #' @return The path to the file, invisibly.
 use_external_js_file <- function(
   url,
-  name,
+  name = NULL,
   pkg = get_golem_wd(),
   dir = "inst/app/www",
   open = FALSE,
   dir_create = TRUE
-) {
+    ) {
   old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
@@ -31,17 +35,24 @@ use_external_js_file <- function(
     name <- basename(url)
   }
 
-  check_name_length(name)
+  check_name_length_is_one(name)
 
   name <- file_path_sans_ext(name)
   new_file <- sprintf("%s.js", name)
 
-  dir_created <- create_if_needed(
-    dir,
-    type = "directory"
+  dir_created <- tryCatch(
+    create_if_needed(
+      dir,
+      type = "directory"
+    ),
+    error = function(e) {
+      out <- FALSE
+      names(out) <- e[[1]]
+      return(out)
+    }
   )
 
-  if (!dir_created) {
+  if (isFALSE(dir_created)) {
     cat_dir_necessary()
     return(invisible(FALSE))
   }
@@ -67,7 +78,7 @@ use_external_js_file <- function(
 
   cat_start_download()
 
-  utils::download.file(url, where)
+  utils_download_file(url, where)
 
   file_created_dance(
     where,
@@ -85,12 +96,12 @@ use_external_js_file <- function(
 #' @rdname use_files
 use_external_css_file <- function(
   url,
-  name,
+  name = NULL,
   pkg = get_golem_wd(),
   dir = "inst/app/www",
   open = FALSE,
   dir_create = TRUE
-) {
+    ) {
   old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
@@ -98,17 +109,24 @@ use_external_css_file <- function(
     name <- basename(url)
   }
 
-  check_name_length(name)
+  check_name_length_is_one(name)
 
   name <- file_path_sans_ext(name)
   new_file <- sprintf("%s.css", name)
 
-  dir_created <- create_if_needed(
-    dir,
-    type = "directory"
+  dir_created <- tryCatch(
+    create_if_needed(
+      dir,
+      type = "directory"
+    ),
+    error = function(e) {
+      out <- FALSE
+      names(out) <- e[[1]]
+      return(out)
+    }
   )
 
-  if (!dir_created) {
+  if (isFALSE(dir_created)) {
     cat_dir_necessary()
     return(invisible(FALSE))
   }
@@ -134,7 +152,7 @@ use_external_css_file <- function(
 
   cat_start_download()
 
-  utils::download.file(url, where)
+  utils_download_file(url, where)
 
   file_created_dance(
     where,
@@ -157,7 +175,7 @@ use_external_html_template <- function(
   dir = "inst/app/www",
   open = FALSE,
   dir_create = TRUE
-) {
+    ) {
   old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
@@ -166,14 +184,21 @@ use_external_html_template <- function(
     file_path_sans_ext(name)
   )
 
-  check_name_length(name)
+  check_name_length_is_one(name)
 
-  dir_created <- create_if_needed(
-    dir,
-    type = "directory"
+  dir_created <- tryCatch(
+    create_if_needed(
+      dir,
+      type = "directory"
+    ),
+    error = function(e) {
+      out <- FALSE
+      names(out) <- e[[1]]
+      return(out)
+    }
   )
 
-  if (!dir_created) {
+  if (isFALSE(dir_created)) {
     cat_dir_necessary()
     return(invisible(FALSE))
   }
@@ -190,9 +215,16 @@ use_external_html_template <- function(
     return(invisible(FALSE))
   }
 
+  if (file_ext(url) != "html") {
+    cat_red_bullet(
+      "File not added (URL must end with .html extension)"
+    )
+    return(invisible(FALSE))
+  }
+
   cat_start_download()
 
-  utils::download.file(url, where)
+  utils_download_file(url, where)
 
   cat_downloaded(where)
 
@@ -211,28 +243,34 @@ use_external_html_template <- function(
 #' @rdname use_files
 use_external_file <- function(
   url,
-  name,
+  name = NULL,
   pkg = get_golem_wd(),
   dir = "inst/app/www",
   open = FALSE,
   dir_create = TRUE
-) {
-  check_name_length(name)
-
+    ) {
   if (missing(name)) {
     name <- basename(url)
   }
 
+  check_name_length_is_one(name)
 
   old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
-  dir_created <- create_if_needed(
-    dir,
-    type = "directory"
+  dir_created <- tryCatch(
+    create_if_needed(
+      dir,
+      type = "directory"
+    ),
+    error = function(e) {
+      out <- FALSE
+      names(out) <- e[[1]]
+      return(out)
+    }
   )
 
-  if (!dir_created) {
+  if (isFALSE(dir_created)) {
     cat_dir_necessary()
     return(invisible(FALSE))
   }
@@ -251,22 +289,31 @@ use_external_file <- function(
 
   cat_start_download()
 
-  utils::download.file(url, where)
+  utils_download_file(url, where)
 
   cat_downloaded(where)
+
+  file_created_dance(
+    where,
+    after_creation_message_any_file,
+    pkg,
+    dir,
+    name,
+    open,
+    open_or_go_to = FALSE
+  )
 }
 
 #' @export
 #' @rdname use_files
 use_internal_js_file <- function(
   path,
-  name,
+  name = NULL,
   pkg = get_golem_wd(),
   dir = "inst/app/www",
   open = FALSE,
   dir_create = TRUE
-) {
-  check_name_length(name)
+    ) {
   old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
@@ -274,15 +321,24 @@ use_internal_js_file <- function(
     name <- basename(path)
   }
 
+  check_name_length_is_one(name)
+
   name <- file_path_sans_ext(name)
   new_file <- sprintf("%s.js", name)
 
-  dir_created <- create_if_needed(
-    dir,
-    type = "directory"
+  dir_created <- tryCatch(
+    create_if_needed(
+      dir,
+      type = "directory"
+    ),
+    error = function(e) {
+      out <- FALSE
+      names(out) <- e[[1]]
+      return(out)
+    }
   )
 
-  if (!dir_created) {
+  if (isFALSE(dir_created)) {
     cat_dir_necessary()
     return(invisible(FALSE))
   }
@@ -325,14 +381,12 @@ use_internal_js_file <- function(
 #' @rdname use_files
 use_internal_css_file <- function(
   path,
-  name,
+  name = NULL,
   pkg = get_golem_wd(),
   dir = "inst/app/www",
   open = FALSE,
   dir_create = TRUE
-) {
-  check_name_length(name)
-
+    ) {
   old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
@@ -340,15 +394,24 @@ use_internal_css_file <- function(
     name <- basename(path)
   }
 
+  check_name_length_is_one(name)
+
   name <- file_path_sans_ext(name)
   new_file <- sprintf("%s.css", name)
 
-  dir_created <- create_if_needed(
-    dir,
-    type = "directory"
+  dir_created <- tryCatch(
+    create_if_needed(
+      dir,
+      type = "directory"
+    ),
+    error = function(e) {
+      out <- FALSE
+      names(out) <- e[[1]]
+      return(out)
+    }
   )
 
-  if (!dir_created) {
+  if (isFALSE(dir_created)) {
     cat_dir_necessary()
     return(invisible(FALSE))
   }
@@ -396,23 +459,30 @@ use_internal_html_template <- function(
   dir = "inst/app/www",
   open = FALSE,
   dir_create = TRUE
-) {
+    ) {
   old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
-  check_name_length(name)
+  check_name_length_is_one(name)
 
   new_file <- sprintf(
     "%s.html",
     file_path_sans_ext(name)
   )
 
-  dir_created <- create_if_needed(
-    dir,
-    type = "directory"
+  dir_created <- tryCatch(
+    create_if_needed(
+      dir,
+      type = "directory"
+    ),
+    error = function(e) {
+      out <- FALSE
+      names(out) <- e[[1]]
+      return(out)
+    }
   )
 
-  if (!dir_created) {
+  if (isFALSE(dir_created)) {
     cat_dir_necessary()
     return(invisible(FALSE))
   }
@@ -429,6 +499,13 @@ use_internal_html_template <- function(
     return(invisible(FALSE))
   }
 
+  if (file_ext(path) != "html") {
+    cat_red_bullet(
+      "File not added (URL must end with .html extension)"
+    )
+    return(invisible(FALSE))
+  }
+
   cat_start_copy()
 
   fs_file_copy(path, where)
@@ -449,27 +526,34 @@ use_internal_html_template <- function(
 #' @rdname use_files
 use_internal_file <- function(
   path,
-  name,
+  name = NULL,
   pkg = get_golem_wd(),
   dir = "inst/app/www",
   open = FALSE,
   dir_create = TRUE
-) {
+    ) {
   if (missing(name)) {
     name <- basename(path)
   }
 
-  check_name_length(name)
+  check_name_length_is_one(name)
 
   old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
-  dir_created <- create_if_needed(
-    dir,
-    type = "directory"
+  dir_created <- tryCatch(
+    create_if_needed(
+      dir,
+      type = "directory"
+    ),
+    error = function(e) {
+      out <- FALSE
+      names(out) <- e[[1]]
+      return(out)
+    }
   )
 
-  if (!dir_created) {
+  if (isFALSE(dir_created)) {
     cat_dir_necessary()
     return(invisible(FALSE))
   }
@@ -491,4 +575,14 @@ use_internal_file <- function(
   fs_file_copy(path, where)
 
   cat_copied(where)
+
+  file_created_dance(
+    where,
+    after_creation_message_any_file,
+    pkg,
+    dir,
+    name,
+    open,
+    open_or_go_to = FALSE
+  )
 }
